@@ -12,8 +12,8 @@
  * everything is a valid host, and let SendMail worry about it.
  */
 
-#include "../../h/mh.h"
-#include "../../zotnet/mts/mts.h"
+#include <h/mh.h>
+#include <zotnet/mts/mts.h>
 
 #ifdef SOCKETS
 # include <netdb.h>
