@@ -253,8 +253,8 @@ sm_init (char *client, char *server, int watch, int verbose,
 	    return RP_OK;
     }
 }
-#else /* SMTP */
 
+#else /* SMTP */
 
 int
 sm_init (char *client, char *server, int watch, int verbose,
@@ -278,15 +278,13 @@ sm_init (char *client, char *server, int watch, int verbose,
 	goto send_options;
 
     if (client == NULL || *client == '\0')
-	client = clientname;
+	if (clientname)
+	    client = clientname;
+	else
+	    client = LocalName();	/* no clientname -> LocalName */
 # ifdef ZMAILER
     if (client == NULL || *client == '\0')
 	client = "localhost";
-# else
-#  if !defined(SENDMTS) || defined(MMDFII) || defined(SVR4)
-    if (client == NULL || *client == 0)
-	client = LocalName ();
-#  endif
 # endif	/* not ZMAILER */
 
     if ((sd1 = rclient (server, "tcp", "smtp")) == NOTOK)
@@ -628,7 +626,7 @@ sm_end (int type)
     }
 
 #ifndef	SMTP
-    status = pidwait (sm_child);
+    status = pidwait (sm_child, OK);
 
     sm_child = NOTOK;
 #else	/* SMTP */
