@@ -5,9 +5,9 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/addrsbr.h"
-#include "../zotnet/mf/mf.h"
+#include <h/mh.h>
+#include <h/addrsbr.h>
+#include <zotnet/mf/mf.h>
 
 #ifdef BERK
 #include <ctype.h>
@@ -294,7 +294,7 @@ register char   *addrs;
     if ((ap = getadrx (addrs ? addrs : "")) == NULL)
 	return NULL;
 
-    (void) strcpy (adr, ap->text);
+    strcpy (adr, ap->text);
     pers = ap->pers;
     mbox = ap->mbox;
     host = ap->host;
@@ -303,7 +303,7 @@ register char   *addrs;
     ingrp = ap->ingrp;
     note = ap->note;
     if (ap->err && *ap->err)
-	(void) strcpy (err, ap->err);
+	strcpy (err, ap->err);
 
     return adr;
 #endif /* not BERK */
@@ -329,7 +329,7 @@ getm (char *str, char *dfhost, int dftype, int wanthost, char *eresult)
 
     if (err && err[0]) {
 	if (eresult)
-	    (void) strcpy (eresult, err);
+	    strcpy (eresult, err);
 	else
 	    if (wanthost == AD_HOST)
 		admonish (NULL, "bad address '%s' - %s", str, err);
@@ -343,7 +343,7 @@ getm (char *str, char *dfhost, int dftype, int wanthost, char *eresult)
 	    && grp == NULL) {
 #endif /* not BERK */
 	if (eresult)
-	    (void) strcpy (eresult, "null address");
+	    strcpy (eresult, "null address");
 	else
 	    if (wanthost == AD_HOST)
 		admonish (NULL, "null address '%s'", str);
@@ -352,7 +352,7 @@ getm (char *str, char *dfhost, int dftype, int wanthost, char *eresult)
 #ifndef	BERK
     if (mbox == NULL && grp == NULL) {
 	if (eresult)
-	    (void) strcpy (eresult, "no mailbox in address");
+	    strcpy (eresult, "no mailbox in address");
 	else
 	    if (wanthost == AD_HOST)
 		admonish (NULL, "no mailbox in address '%s'", str);
@@ -365,10 +365,10 @@ getm (char *str, char *dfhost, int dftype, int wanthost, char *eresult)
     }
 #endif /* not BERK */
 
-    mp = (struct mailname  *) calloc ((unsigned) 1, sizeof *mp);
+    mp = (struct mailname *) calloc ((unsigned) 1, sizeof(*mp));
     if (mp == NULL) {
 	if (eresult)
-	   (void) strcpy (eresult, "insufficient memory to represent address");
+	   strcpy (eresult, "insufficient memory to represent address");
 	else
 	    if (wanthost == AD_HOST)
 		adios (NULL, "insufficient memory to represent address");
@@ -542,53 +542,53 @@ auxformat (struct mailname *mp, int extras)
 #ifdef	BERK
     /* this "if" is a crufty hack to handle "visible" aliases */
     if (mp->m_pers && !extras)
-	(void) sprintf (buffer, "%s <%s>", mp->m_pers, mp->m_mbox);
+	sprintf (buffer, "%s <%s>", mp->m_pers, mp->m_mbox);
     else
-	(void) strcpy (buffer, mp->m_text);
+	strcpy (buffer, mp->m_text);
 #else /* not BERK */
 
 #ifdef	MF
     if (up && mp->m_type == UUCPHOST)
 #ifdef	MMDFMTS
-	(void) sprintf (addr, "%s!%s%%%s@%s", mp->m_host, mp->m_mbox,
+	sprintf (addr, "%s!%s%%%s@%s", mp->m_host, mp->m_mbox,
 		up, LocalName ());
 #else /* not MMDFMTS */
-	(void) sprintf (addr, "%s@%s.%s", mp->m_mbox, mp->m_host, up);
+	sprintf (addr, "%s@%s.%s", mp->m_mbox, mp->m_host, up);
 #endif /* not MMDFMTS */
     else 
 #endif /* MF */
 
 #ifdef	DUMB
 	if (mp->m_nohost)
-	    (void) strcpy (addr, mp->m_mbox ? mp->m_mbox : "");
+	    strcpy (addr, mp->m_mbox ? mp->m_mbox : "");
 	else
 #endif /* DUMB */
 
 #ifndef	BANG
 	if (mp->m_type != UUCPHOST)
-	    (void) sprintf (addr, mp->m_host ? "%s%s@%s" : "%s%s",
+	    sprintf (addr, mp->m_host ? "%s%s@%s" : "%s%s",
 		mp->m_path ? mp->m_path : "", mp->m_mbox, mp->m_host);
 	else
 #endif /* not BANG */
-	    (void) sprintf (addr, "%s!%s", mp->m_host, mp->m_mbox);
+	    sprintf (addr, "%s!%s", mp->m_host, mp->m_mbox);
 
     if (!extras)
 	return addr;
 
     if (mp->m_pers || mp->m_path)
 	if (mp->m_note)
-	    (void) sprintf (buffer, "%s %s <%s>",
+	    sprintf (buffer, "%s %s <%s>",
 		    legal_person (mp->m_pers ? mp->m_pers : mp->m_mbox),
 		    mp->m_note, addr);
 	else
-	    (void) sprintf (buffer, "%s <%s>",
+	    sprintf (buffer, "%s <%s>",
 		    legal_person (mp->m_pers ? mp->m_pers : mp->m_mbox),
 		    addr);
     else
 	if (mp->m_note)
-	    (void) sprintf (buffer, "%s %s", addr, mp->m_note);
+	    sprintf (buffer, "%s %s", addr, mp->m_note);
 	else
-	    (void) strcpy (buffer, addr);
+	    strcpy (buffer, addr);
 #endif /* not BERK */
 
     return buffer;
@@ -621,9 +621,9 @@ adrsprintf (char *local, char *domain)
 	domain = LocalName ();
 
 #ifndef	BANG
-    (void) sprintf (addr, "%s@%s", local, domain);
+    sprintf (addr, "%s@%s", local, domain);
 #else /* BANG */
-    (void) sprintf (addr, "%s!%s", domain, local);
+    sprintf (addr, "%s!%s", domain, local);
 #endif /* BANG */
 
     return addr;
@@ -767,7 +767,7 @@ local_test: ;
 	    }
 #else /* not BERK */
     for (mp = &mq; mp = mp->m_next;) {
-	if (np->m_mbox == NULL)
+	if (!np->m_mbox)
 	    continue;
 	if ((len = strlen (cp = np->m_mbox))
 		< (i = strlen (pp = mp->m_mbox)))
