@@ -5,8 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/signals.h"
+#include <h/mh.h>
+#include <h/signals.h>
 #include <setjmp.h>
 #include <signal.h>
 
