@@ -1,11 +1,11 @@
 
 /*
- * m_getdefs.c -- read the user's MH environment
+ * m_getdefs.c -- read the user's nmh environment
  *
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <errno.h>
 #include <pwd.h>
 
@@ -32,7 +32,7 @@ m_getdefs(void)
 
     if (defpath)
 	return;
-    if (mypath == NULL) {
+    if (!mypath) {
 	if (mypath = getenv ("HOME"))
 	    mypath = getcpy (mypath);
 	else
