@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 
 struct msgs *
@@ -26,7 +26,7 @@ m_remsg (struct msgs *mp, int lo, int hi)
 	return mp;
 
 #ifndef	MTR
-    mp = (struct msgs  *) realloc ((char *) mp, MHSIZE (mp, lo, hi));
+    mp = (struct msgs *) realloc ((char *) mp, MHSIZE (mp, lo, hi));
     if (mp == NULL)
 	adios (NULL, "unable to re-allocate folder storage");
 #else	/* MTR */
