@@ -11,7 +11,7 @@
  * have to send me the code.
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 #if defined (BSD42) || defined (hpux) || defined(SVR4) || \
 	defined(ncr) || defined (_AIX) || defined(AUX)
@@ -28,7 +28,7 @@ makedir (char *dir)
     pid_t pid;
     register char *cp;
     register char *c;
-    char path[MAXPATHLEN];
+    char path[PATH_MAX];
 
     m_update();
     fflush(stdout);
