@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 
 int
@@ -17,17 +17,17 @@ smatch(char *string, struct swit *swp)
 
     firstone = UNKWNSW;
 
-    if (string == 0)
+    if (!string)
 	return firstone;
 
-    for (stringlen = strlen (string), tp = swp; tcp = tp->sw; tp++) {
+    for (stringlen = strlen(string), tp = swp; tcp = tp->sw; tp++) {
 	if (stringlen < abs (tp->minchars))
 	    continue;		/* no match */
 	for (sp = string; *sp == *tcp++;) {
 	    if (*sp++ == 0)
 		return (tp - swp);/* exact match */
 	}
-	if (*sp != 0) {
+	if (*sp) {
 	    if (*sp != ' ')
 		continue;	/* no match */
 	    if (*--tcp == 0)
