@@ -5,9 +5,9 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/addrsbr.h"
-#include "../h/aliasbr.h"
+#include <h/mh.h>
+#include <h/addrsbr.h>
+#include <h/aliasbr.h>
 
 /*
  * maximum number of names
@@ -71,7 +71,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
