@@ -9,6 +9,10 @@
 #include <h/signals.h>
 #include <zotnet/bboards/bboards.h>
 
+#ifdef POP
+# include <h/popsbr.h>
+#endif
+
 #ifdef BPOP
 # include <zotnet/mts.h>
 #endif
@@ -988,7 +992,7 @@ char   *s;
 	adios (NULL, "insufficient memory");
     bb->bb_name = getcpy (name);
 #ifdef	NNTP
-    if (index(name, '.')) {
+    if (strchr(name, '.')) {
 	char *cp;
 	bb->bb_aka = getip (name);
 	for (cp = *bb->bb_aka; *cp; cp++)
