@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 static struct swit switches[] = {
 #define	ANNOSW	0
@@ -89,7 +89,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -190,11 +190,11 @@ main (int argc, char **argv)
 	adios (NULL, "can't mix files and folders/msgs");
 
     if (form) {
-	if ((in = open (libpath (form), 0)) == NOTOK)
+	if ((in = open (etcpath (form), 0)) == NOTOK)
 	    adios (form, "unable to open form file");
     }
     else {
-	if ((in = open (libpath (distcomps), 0)) == NOTOK)
+	if ((in = open (etcpath (distcomps), 0)) == NOTOK)
 	    adios (distcomps, "unable to open default components file");
 	form = distcomps;
     }
