@@ -208,7 +208,7 @@ mbx_read (FILE *fp, long pos, struct drop **drops, int noisy)
 	if (dp->d_start != (long) pos) {
 	    dp->d_id = 0;
 	    dp->d_size = (long) size;
-	    dp->d_stop = (long) pos;
+	    dp->d_stop = pos;
 	    dp++;
 	}
 	pos += ld2;
@@ -238,10 +238,11 @@ mbx_read (FILE *fp, long pos, struct drop **drops, int noisy)
 
 int
 mbx_write(char *mailbox, int md, FILE *fp, int id, long last,
-           long pos, long stop, int mapping, int noisy)
+           long pos, off_t stop, int mapping, int noisy)
 {
     register int i, j, size;
-    long start, off;
+    off_t start;
+    long off;
     register char *cp;
     char buffer[BUFSIZ];
 
@@ -249,7 +250,7 @@ mbx_write(char *mailbox, int md, FILE *fp, int id, long last,
     j = strlen (mmdlm1);
     if (write (md, mmdlm1, j) != j)
 	return NOTOK;
-    start = (long) lseek (md, (off_t) 0, 1);
+    start = lseek (md, (off_t) 0, 1);
     size = 0;
 
     fseek (fp, pos, 0);
@@ -268,7 +269,7 @@ mbx_write(char *mailbox, int md, FILE *fp, int id, long last,
 		    size++;
     }
 
-    stop = (long) lseek (md, (off_t) 0, 1);
+    stop = lseek (md, (off_t) 0, 1);
     j = strlen (mmdlm2);
     if (write (md, mmdlm2, j) != j)
 	return NOTOK;
@@ -283,7 +284,8 @@ int
 mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 {
     register int i, j, size;
-    long start, stop, pos;
+    off_t start, stop;
+    long pos;
     register char *cp;
     char buffer[BUFSIZ];
     register FILE *fp;
@@ -297,7 +299,7 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 	    j = strlen (mmdlm1);
 	    if (write (md, mmdlm1, j) != j)
 		return NOTOK;
-	    start = (long) lseek (md, (off_t) 0, 1);
+	    start = lseek (md, (off_t) 0, 1);
 
 	    if (text) {
 		i = strlen (text);
@@ -325,7 +327,7 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 			    size++;
 	    }
 
-	    stop = (long) lseek (md, (off_t) 0, 1);
+	    stop = lseek (md, (off_t) 0, 1);
 	    j = strlen (mmdlm2);
 	    if (write (md, mmdlm2, j) != j)
 		return NOTOK;
@@ -341,7 +343,7 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 		close (j);
 		return NOTOK;
 	    }
-	    start = (long) lseek (md, (off_t) 0, 1);
+	    start = lseek (md, (off_t) 0, 1);
 
 	    if (text) {
 		i = strlen (text);
@@ -375,7 +377,7 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 
 	    fclose (fp);
 	    lseek (fd, (off_t) 0, 2);
-	    stop = (long) lseek (md, (off_t)0, 1);
+	    stop = lseek (md, (off_t)0, 1);
 	    if (mapping)
 		map_write (mailbox, md, 0, (long)0, start, stop, pos, size, noisy);
 
@@ -385,7 +387,7 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 
 
 int
-mbx_size (int md, long start, long stop)
+mbx_size (int md, off_t start, off_t stop)
 {
     register int i, fd;
     register long pos;
@@ -442,7 +444,7 @@ map_name (char *file)
 int
 map_read (char *file, long pos, struct drop **drops, int noisy)
 {
-    register int i, j, md, msgp;
+    register int i, md, msgp;
     register char *cp;
     struct drop d;
     register struct drop *mp, *dp;
@@ -471,6 +473,8 @@ map_read (char *file, long pos, struct drop **drops, int noisy)
     else {
 #ifdef	NTOHLSWAP
 	register struct drop *tdp;
+	int j;
+
 	for (j = 0, tdp = dp; j < i / sizeof(*dp); j++, tdp++) {
 	    tdp->d_id = ntohl(tdp->d_id);
 	    tdp->d_size = ntohl(tdp->d_size);
@@ -488,8 +492,8 @@ map_read (char *file, long pos, struct drop **drops, int noisy)
 
 
 int
-map_write (char *mailbox, int md, int id, long last, long start,
-           long stop, long pos, int size, int noisy)
+map_write (char *mailbox, int md, int id, long last, off_t start,
+           off_t stop, long pos, int size, int noisy)
 {
     register int i;
     int clear, fd, td;
@@ -552,8 +556,8 @@ map_write (char *mailbox, int md, int id, long last, long start,
 	dp = &d2;
 	dp->d_id = id;
 	dp->d_size = (long) (size ? size : mbx_size (fd, start, stop));
-	dp->d_start = (long) start;
-	dp->d_stop = (long) stop;
+	dp->d_start = start;
+	dp->d_stop = stop;
 	lseek (fd, (off_t) (++d1.d_id * sizeof *dp), 0);
 	if (write (fd, (char *) dp, sizeof *dp) != sizeof *dp) {
 	    if (noisy)
@@ -566,7 +570,7 @@ map_write (char *mailbox, int md, int id, long last, long start,
     dp = &d1;
     dp->d_size = DRVRSN;
     dp->d_start = (long) last;
-    dp->d_stop = (long) lseek (md, (off_t)0, 1);
+    dp->d_stop = lseek (md, (off_t)0, 1);
 
     lseek (fd, (off_t) 0, 0);
     if (write (fd, (char *) dp, sizeof *dp) != sizeof *dp) {
@@ -622,7 +626,7 @@ map_chk (char *file, int fd, struct drop *dp, long pos, int noisy)
 	return NOTOK;
     }
 
-    if (dp->d_stop != (long) pos) {
+    if (dp->d_stop != pos) {
 	if (noisy && pos != (long) 0)
 	    admonish (NULL,
 		    "%s: pointer mismatch or incomplete index (%ld!=%ld)", 
