@@ -21,6 +21,7 @@
 
 #ifdef POP
 # include <h/dropsbr.h>
+# include <h/popsbr.h>
 #endif
 
 #ifdef KPOP
@@ -68,7 +69,7 @@
 # define TMAminc(a)  0
 #endif
 
-static struct swit  switches[] = {
+static struct swit switches[] = {
 #define	AUDSW                      0
     { "audit audit-file", 0 },
 #define	NAUDSW                     1
@@ -88,9 +89,9 @@ static struct swit  switches[] = {
 #define	FMTSW                      8
     { "format string", 5 },
 #define	HOSTSW                     9
-    { "host host", POPminc (-4) },
+    { "host hostname", POPminc (-4) },
 #define	USERSW                    10
-    { "user user", POPminc (-4) },
+    { "user username", POPminc (-4) },
 #define	PACKSW                    11
     { "pack file", POPminc (-4) },
 #define	NPACKSW                   12
@@ -169,24 +170,10 @@ main (int argc, char **argv)
 {
     int chgflag = 1, trnflag = 1, decflag = 1;
     int noisy = 1, width = 0, locked = 0;
-
-#ifdef	MF
-    int uucp = 1;
-#endif
-
-#ifdef	POP
-    int nmsgs, nbytes, p = 0;
-#endif
-
-    int rpop = 1, i, hghnum, msgnum;
+    int rpop = 0, i, hghnum, msgnum;
     char *cp, *maildir, *folder = NULL, *form = NULL;
     char *format = NULL, *audfile = NULL, *from = NULL;
     char *host = NULL;
-
-#ifdef	POP
-    char *pass = NULL;
-#endif
-
     char *newmail, buf[100], **ap;
     char **argp, *nfs, *arguments[MAXARGS];
     char *user = NULL;
@@ -194,6 +181,15 @@ main (int argc, char **argv)
     struct stat st, s1;
     FILE *in, *aud = NULL;
 
+#ifdef MF
+    int uucp = 1;
+#endif
+
+#ifdef POP
+    int nmsgs, nbytes, p = 0;
+    char *pass = NULL;
+#endif
+
 #ifdef MHE
     FILE *mhe = NULL;
 #endif
@@ -397,7 +393,11 @@ main (int argc, char **argv)
 	else
 	    ruserpass (host, &user, &pass);
 
+#if defined(RPOP) || defined(APOP)
 	if (pop_init (host, user, pass, snoop, rpop) == NOTOK
+#else
+	if (pop_init (host, user, pass, snoop) == NOTOK
+#endif
 		|| pop_stat (&nmsgs, &nbytes) == NOTOK)
 	    adios (NULL, "%s", response);
 	if (rpop > 0)
