@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <pwd.h>
 
 static char *message[] = {
@@ -71,7 +71,7 @@ main (int argc, char **argv)
 
     cp = concat (mypath, "/", "Mail", NULL);
     if (stat (cp, &st) != NOTOK) {
-	if ((st.st_mode & S_IFMT) == S_IFDIR) {
+	if (S_ISDIR(st.st_mode)) {
 	    cp = concat ("You already have the standard MH directory \"",
 		    cp, "\".\nDo you want to use it for MH? ", NULL);
 	    if (gans (cp, anoyes))
