@@ -36,6 +36,7 @@ static char tmpfil[BUFSIZ];
 static RETSIGTYPE intrser (int);
 
 
+int
 main (int argc, char **argv)
 {
     pid_t child_id;
@@ -155,27 +156,27 @@ main (int argc, char **argv)
 
     for (i = 0; (child_id = fork()) == NOTOK && i < 5; i++)
 	sleep (5);
-    switch (child_id) {
-	case NOTOK: 		/* report failure and then send it */
-	    admonish (NULL, "unable to fork");
 
-	case OK:
-	    execvp (postproc, vec);
-	    fprintf (stderr, "unable to exec ");
-	    perror (postproc);
+    if (child_id == NOTOK) {
+	/* report failure and then send it */
+	admonish (NULL, "unable to fork");
+    } else if (child_id) {
+	/* parent process */
+	if ((status = pidXwait(child_id, postproc))) {
+	    fprintf (stderr, "Letter saved in dead.letter\n");
+	    execl ("/bin/mv", "mv", tmpfil, "dead.letter", NULL);
+	    execl ("/usr/bin/mv", "mv", tmpfil, "dead.letter", NULL);
+	    perror ("mv");
 	    _exit (-1);
-
-	default: 
-	    if (status = pidXwait(child_id, postproc)) {
-		fprintf (stderr, "Letter saved in dead.letter\n");
-		execl ("/bin/mv", "mv", tmpfil, "dead.letter", NULL);
-		execl ("/usr/bin/mv", "mv", tmpfil, "dead.letter", NULL);
-		perror ("mv");
-		_exit (-1);
-	    }
-
-	    unlink (tmpfil);
-	    done (status ? 1 : 0);
+	}
+	unlink (tmpfil);
+	done (status ? 1 : 0);
+    } else {
+	/* child process */
+	execvp (postproc, vec);
+	fprintf (stderr, "unable to exec ");
+	perror (postproc);
+	_exit (-1);
     }
 }
 
