@@ -8,9 +8,10 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 extern char *mhlibdir;		/* NB: this will change soon */
+
 char *sbackup = BACKUP_PREFIX;
 char *slink = LINK;
 
@@ -51,7 +52,7 @@ main(int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -120,44 +121,45 @@ main(int argc, char **argv)
     done (missed);
 }
 
-static struct procs {
-	char *p_name;
-	char **p_field;
-} procs [] = {
-     { "context",	&context	},
-     { "faceproc",	&faceproc	},
-     { "fileproc",	&fileproc	},
-     { "foldprot",	&foldprot	},
-     { "incproc",	&incproc	},
-     { "installproc",	&installproc 	},
-     { "lproc",   	&lproc		},
-     { "mailproc",	&mailproc	},
-     { "mhlproc",	&mhlproc	},
-     { "moreproc",	&moreproc	},
-     { "msgprot",	&msgprot	},
-     { "mshproc",	&mshproc	},
-     { "packproc",	&packproc	},
-     { "postproc",	&postproc	},
-     { "rmfproc",	&rmfproc	},
-     { "rmmproc",	&rmmproc	},
-     { "sendproc",	&sendproc	},
-     { "showproc",	&showproc	},
-     { "slocalproc",	&slocalproc	},
-     { "version",	&version	},
-     { "vmhproc",	&vmhproc	},
-     { "whatnowproc",	&whatnowproc	},
-     { "whomproc",	&whomproc	},
-     { "libdir",	&mhlibdir       },
-     { "sbackup",       &sbackup        },
-     { "link",          &slink          },
+struct proc {
+    char *p_name;
+    char **p_field;
+};
 
-     { NULL, NULL },
+static struct proc procs [] = {
+     { "context",     &context },
+     { "faceproc",    &faceproc },
+     { "fileproc",    &fileproc },
+     { "foldprot",    &foldprot },
+     { "incproc",     &incproc },
+     { "installproc", &installproc  },
+     { "lproc",       &lproc },
+     { "mailproc",    &mailproc },
+     { "mhlproc",     &mhlproc },
+     { "moreproc",    &moreproc },
+     { "msgprot",     &msgprot },
+     { "mshproc",     &mshproc },
+     { "packproc",    &packproc },
+     { "postproc",    &postproc },
+     { "rmfproc",     &rmfproc },
+     { "rmmproc",     &rmmproc },
+     { "sendproc",    &sendproc },
+     { "showproc",    &showproc },
+     { "slocalproc",  &slocalproc },
+     { "version",     &version },
+     { "vmhproc",     &vmhproc },
+     { "whatnowproc", &whatnowproc },
+     { "whomproc",    &whomproc },
+     { "libdir",      &mhlibdir },
+     { "sbackup",     &sbackup },
+     { "link",        &slink },
+     { NULL,          NULL },
 };
 
 static char *
 p_find(char *str)
 {
-    register struct procs *ps;
+    register struct proc *ps;
 
     for (ps = procs; ps->p_name; ps++)
 	if (uleq (ps->p_name, str))
