@@ -1263,17 +1263,22 @@ markcmd (char **args)
 	}
 
     if (listsw) {
-	int     bits = FFATTRSLOT;
+	int bits = FFATTRSLOT;
 
-	if (seqp == 0)
+#define empty(s) ((s) ? (s) : "")
+
+	if (!seqp) {
 	    for (i = 0; mp->msgattrs[i]; i++)
 		printf ("%s%s: %s\n", mp->msgattrs[i],
 			mp->attrstats & (1 << (bits + i))
 			? " (private)" : "",
-			m_seq (mp, mp->msgattrs[i]));
-	else
+			empty(m_seq (mp, mp->msgattrs[i])));
+	} else {
 	    for (seqp = 0; seqs[seqp]; seqp++)
-		printf ("%s%s: %s\n", seqs[seqp], m_seq (mp, seqs[seqp]));
+		printf ("%s%s: %s\n", seqs[seqp], empty(m_seq (mp, seqs[seqp])));
+	}
+
+#undef empty
 
 	interrupted = 0;
 	if (debugsw)
