@@ -5,8 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../zotnet/tws/tws.h"
+#include <h/mh.h>
+#include <zotnet/tws/tws.h>
 
 static struct swit switches[] = {
 #define	ANDSW                   0
@@ -86,7 +86,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-') {
 	    if (*++cp == '-') {
 		vec[vecp++] = --cp;
