@@ -19,6 +19,7 @@
 # include <h/md5.h>
 #endif
 
+#include <h/popsbr.h>
 #include <signal.h>
 
 #define	TRM	"."
@@ -56,10 +57,8 @@ static char xtnd_name[512];	/* INCREDIBLE HACK!! */
 static char *pop_auth (char *, char *)
 #endif
 
-#if !defined(NNTP) && defined(MPOP)
-int command(const char *, ...);
-int multiline(void);
-#else
+#if defined(NNTP) || !defined(MPOP)
+/* otherwise they are not static functions */
 static int command(const char *, ...);
 static int multiline(void);
 #endif
@@ -71,7 +70,6 @@ static int putline (char *, FILE *);
 
 
 #if !defined(NNTP) && defined(APOP)
-
 static char *
 pop_auth (char *user, char *pass)
 {
@@ -122,10 +120,10 @@ pop_init (char *host, char *user, char *pass, int snoop)
 
 #ifdef APOP
     int apop;
-#else
-# ifndef RPOP	/* !APOP && !RPOP */
+#endif
+
+#if !defined(RPOP) && !defined(APOP)
     int	rpop = 0;
-# endif
 #endif
 
 #ifdef APOP
@@ -134,7 +132,7 @@ pop_init (char *host, char *user, char *pass, int snoop)
 #endif
 
 #ifndef NNTP
-#ifndef	KPOP
+#ifndef KPOP
     if ((fd1 = client (host, "tcp", POPSERVICE, rpop, response)) == NOTOK)
 #else	/* KPOP */
     sprintf (buffer, "%s/%s", POPSERVICE, "kpop");
@@ -170,10 +168,10 @@ pop_init (char *host, char *user, char *pass, int snoop)
 		fprintf (stderr, "<--- %s\n", response);
 #ifndef	NNTP
 	    if (*response == '+') {
-#ifndef	KPOP
+#ifndef KPOP
 #ifdef	APOP
 		if (apop < 0) {
-		    char   *cp = pop_auth (user, pass);
+		    char *cp = pop_auth (user, pass);
 
 		    if (cp && command ("APOP %s", cp) != NOTOK)
 			return OK;
@@ -184,7 +182,7 @@ pop_init (char *host, char *user, char *pass, int snoop)
 		    && command ("%s %s", rpop ? "RPOP" : (pophack++, "PASS"),
 					pass) != NOTOK)
 		return OK;
-#else	/* KPOP */
+#else /* KPOP */
 		if (command ("USER %s", user) != NOTOK
 		    && command ("PASS %s", pass) != NOTOK)
 		return OK;
@@ -212,12 +210,12 @@ pop_init (char *host, char *user, char *pass, int snoop)
 /* NOTREACHED */
 }
 
-#ifndef NNTP
-int
-pop_set (int in, int out, int snoop)
-#else	/* NNTP */
+#ifdef NNTP
 int
 pop_set (int in, int out, int snoop, char *myname)
+#else
+int
+pop_set (int in, int out, int snoop)
 #endif
 {
 
@@ -257,7 +255,6 @@ pop_stat (int *nmsgs, int *nbytes)
 {
 #ifdef NNTP
     char **ap;
-    extern char **brkstring();
 #endif	/* NNTP */
 
 #ifndef	NNTP
@@ -292,26 +289,24 @@ pop_stat (int *nmsgs, int *nbytes)
 int
 pop_exists (int (*action)())
 {
-#ifdef	XMSGS		/* hacked into NNTP 1.5 */
-    if (traverse (action, "XMSGS %d-%d",
-	    (targ_t)xtnd_first, (targ_t)xtnd_last, 0, 0) == OK)
+#ifdef XMSGS		/* hacked into NNTP 1.5 */
+    if (traverse (action, "XMSGS %d-%d", (targ_t) xtnd_first, (targ_t) xtnd_last) == OK)
 	return OK;
 #endif
-    if (traverse (action, "LISTGROUP",	/* provided by INN 1.4 */
-	    0, 0, 0, 0) == OK)
+    /* provided by INN 1.4 */
+    if (traverse (action, "LISTGROUP") == OK)
 	return OK;
-    return traverse (action, "XHDR NONAME %d-%d",
-	    (targ_t)xtnd_first, (targ_t)xtnd_last, 0, 0);
+    return traverse (action, "XHDR NONAME %d-%d", (targ_t) xtnd_first, (targ_t) xtnd_last);
 }
 #endif	/* NNTP */
 
 
-#ifndef BPOP
-int
-pop_list (int msgno, int *nmsgs, int *msgs, int *bytes)
-#else
+#ifdef BPOP
 int
 pop_list (int msgno, int *nmsgs, int *msgs, int *bytes, int *ids)
+#else
+int
+pop_list (int msgno, int *nmsgs, int *msgs, int *bytes)
 #endif
 {
     int i;
@@ -382,9 +377,9 @@ int
 pop_retr (int msgno, int (*action)())
 {
 #ifndef NNTP
-    return traverse (action, "RETR %d", (targ_t) msgno, 0, 0, 0);
+    return traverse (action, "RETR %d", (targ_t) msgno);
 #else	/* NNTP */
-    return traverse (action, "ARTICLE %d", (targ_t) msgno, 0, 0, 0);
+    return traverse (action, "ARTICLE %d", (targ_t) msgno);
 #endif	/* NNTP */
 }
 
@@ -392,10 +387,15 @@ pop_retr (int msgno, int (*action)())
 static int
 traverse (int (*action)(), const char *fmt, ...)
 {
+    int result;
     va_list ap;
     char buffer[sizeof response];
 
-    if (vcommand (fmt, ap) == NOTOK)
+    va_start(ap, fmt);
+    result = vcommand (fmt, ap);
+    va_end(ap);
+
+    if (result == NOTOK)
 	return NOTOK;
     strcpy (buffer, response);
 
@@ -449,9 +449,9 @@ int
 pop_top (int msgno, int lines, int (*action)())
 {
 #ifndef NNTP
-    return traverse (action, "TOP %d %d", (targ_t)msgno, (targ_t)lines, 0, 0);
+    return traverse (action, "TOP %d %d", (targ_t) msgno, (targ_t) lines);
 #else	/* NNTP */
-    return traverse (action, "HEAD %d", (targ_t)msgno, 0, 0, 0);
+    return traverse (action, "HEAD %d", (targ_t) msgno);
 #endif	/* NNTP */
 }
 
@@ -460,15 +460,21 @@ pop_top (int msgno, int lines, int (*action)())
 int
 pop_xtnd (int (*action)(), char *fmt, ...)
 {
+    int result;
+    va_list ap;
     char buffer[BUFSIZ];
-#ifdef NNTP
-    extern char **brkstring();
-    char  **ap;
-#endif	/* NNTP */
 
+#ifdef NNTP
+    char **ap;
+#endif
+
+    va_start(ap, fmt);
 #ifndef NNTP
+    /* needs to be fixed... va_end needs to be added */
     sprintf (buffer, "XTND %s", fmt);
-    return traverse (action, buffer, a, b, c, d);
+    result = traverse (action, buffer, a, b, c, d);
+    va_end(ap);
+    return result;
 #else	/* NNTP */
     sprintf (buffer, fmt, a, b, c, d);
     ap = brkstring (buffer, " ", "\n");	/* a hack, i know... */
@@ -558,7 +564,7 @@ vcommand (const char *fmt, va_list ap)
     vsprintf (buffer, fmt, ap);
     if (poprint)
 	if (pophack) {
-	    if (cp = strchr (buffer, ' '))
+	    if ((cp = strchr (buffer, ' ')))
 		*cp = 0;
 	    fprintf (stderr, "---> %s ********\n", buffer);
 	    if (cp)
