@@ -1,6 +1,6 @@
 
 /*
- * post.c -- enter messages into the transport system
+ * post.c -- enter messages into the mail transport system
  *
  * $Id$
  */
@@ -799,7 +799,7 @@ putfmt (char *name, char *str, FILE *out)
 	    return;
 	}
 
-	if (cp = strrchr(str, '\n'))
+	if ((cp = strrchr(str, '\n')))
 	    *cp = 0;
 	for (cp = pp = str; cp = strchr(pp, ','); pp = cp) {
 	    *cp++ = 0;
@@ -816,7 +816,7 @@ putfmt (char *name, char *str, FILE *out)
 
     tmpaddrs.m_next = NULL;
     for (count = 0; cp = getname (str); count++)
-	if (mp = getm (cp, NULL, 0, AD_HOST, NULL)) {
+	if ((mp = getm (cp, NULL, 0, AD_HOST, NULL))) {
 	    if (tmpaddrs.m_next)
 		np->m_next = mp;
 	    else
@@ -851,7 +851,7 @@ putfmt (char *name, char *str, FILE *out)
 	    np = mp;
 	    if (np->m_gname)
 		putgrp (namep, np->m_gname, out, hdr->flags);
-	    while (cp = getname (pp)) {
+	    while ((cp = getname (pp))) {
 		if (!(mp = getm (cp, NULL, 0, AD_HOST, NULL))) {
 		    badadr++;
 		    continue;
@@ -1219,7 +1219,7 @@ make_bcc_file (void)
     int fd, i;
     pid_t child_id;
     char *vec[6];
-    register FILE   *out;
+    register FILE *out;
 
     strcpy (bccfil, m_tmpfil ("bccs"));
     if ((out = fopen (bccfil, "w")) == NULL)
@@ -1236,7 +1236,7 @@ make_bcc_file (void)
     fprintf (out, "BCC:\n");
 #ifdef MIME
     if (mime) {
-	char   *cp;
+	char *cp;
 
 	if ((cp = strchr(prefix, 'a')) == NULL)
 	    adios (NULL, "lost prefix start");
@@ -1351,7 +1351,7 @@ static void
 verify_all_addresses (int talk)
 {
 #ifndef	MHMTS
-    int     retval;
+    int retval;
 #endif	/* not MHMTS */
 #ifdef	MMDFMTS
 #ifdef	RP_NS
@@ -1861,10 +1861,6 @@ do_text (char *file, int fd)
 
 #ifdef	MMDFMTS
 
-#ifndef	TMA
-/* ARGSUSED */
-#endif	/* TMA */
-
 static void
 do_an_address (struct mailname *lp, int talk, int tma)
 {
@@ -1992,7 +1988,6 @@ do_an_address (struct mailname *lp, int talk, int tma)
 
 
 #ifdef	MHMTS
-/* ARGSUSED */
 
 static void
 do_an_address (struct mailname *lp, int talk, int tma)
@@ -2077,10 +2072,6 @@ do_an_address (struct mailname *lp, int talk, int tma)
 
 #ifdef SENDMTS
 
-#ifndef	TMA
-/* ARGSUSED */
-#endif	/* TMA */
-
 static void
 do_an_address (struct mailname *lp, int talk, int tma)
 {
@@ -2088,7 +2079,7 @@ do_an_address (struct mailname *lp, int talk, int tma)
     register char *mbox, *host;
     char addr[BUFSIZ];
 #ifdef	TMA
-    char    reason[BUFSIZ];
+    char reason[BUFSIZ];
 #endif	/* TMA */
 
     switch (lp->m_type) {
@@ -2158,12 +2149,12 @@ do_an_address (struct mailname *lp, int talk, int tma)
 }
 #endif	/* SENDMTS */
 
-/* SIGNAL HANDLING */
+/*
+ * SIGNAL HANDLING
+ */
 
 #ifndef	MHMTS
 
-/* ARGSUSED */
-
 static RETSIGTYPE
 sigser (int i)
 {
@@ -2269,7 +2260,7 @@ fcc (char *file, char *folder)
 	    _exit (-1);
 
 	default: 
-	    if (status = pidwait (child_id, OK)) {
+	    if ((status = pidwait (child_id, OK))) {
 		if (!verbose)
 		    fprintf (stderr, "  %sFcc %s: ",
 			    msgstate == RESENT ? "Resent-" : "", folder);
@@ -2506,15 +2497,11 @@ usr_hook (struct mailname *lp, int talk, int fd, struct home *hp, char *mailbox)
 static int
 copyfile (int qd, char *tmpfil)
 {
-    int     i,
-            fd;
-    char    buffer[BUFSIZ];
+    int i, fd;
+    char buffer[BUFSIZ];
 
     strcpy (tmpfil, m_tmpfil ("hook"));
-    if ((fd = creat (tmpfil, 0600)) == NOTOK)
-	return NOTOK;
-    close (fd);
-    if ((fd = open (tmpfil, 2)) == NOTOK)
+    if ((fd = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
 	return NOTOK;
 
     lseek (qd, (off_t) 0, 0);
@@ -2602,24 +2589,19 @@ uucpmail (struct mailname *lp, int talk, int fd, int from)
     fflush (stdout);
 }
 
-#ifdef	MF
+#ifdef MF
 static int
 make_uucp_file (int td)
 {
-    int     i,
-            qd,
-            fd;
-    char    tmpfil[BUFSIZ];
+    int i, qd, fd;
+    char tmpfil[BUFSIZ];
 
     lseek (td, (off_t) 0, 0);
     if ((qd = dup (td)) == NOTOK)
 	adios ("fd", "unable to dup");
 
     strcpy (tmpfil, m_tmpfil ("uumf"));
-    if ((fd = creat (tmpfil, 0600)) == NOTOK)
-	adios (tmpfil, "unable to create");
-    close (fd);
-    if ((fd = open (tmpfil, 2)) == NOTOK)
+    if ((fd = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
 	adios (tmpfil, "unable to re-open");
 
     switch (i = mmdf2uucp (qd, fd, 1)) {
