@@ -14,6 +14,7 @@
 #include <h/scansbr.h>
 #include <zotnet/tws/tws.h>
 #include <signal.h>
+#include <fcntl.h>
 
 #ifndef	TTYD
 # include <utmp.h>
@@ -178,11 +179,7 @@ message_fd (char **vec)
     struct stat st;
 
     unlink (mktemp (strcpy (tmpfil, "/tmp/rcvttyXXXXX")));
-    if ((fd = creat (tmpfil, 0600)) == NOTOK)
-	return header_fd ();
-    close (fd);
-
-    if ((fd = open (tmpfil, 2)) == NOTOK)
+    if ((fd = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
 	return header_fd ();
     unlink (tmpfil);
 
@@ -196,38 +193,31 @@ message_fd (char **vec)
 	    if (dup2 (fd, 1) == NOTOK || dup2 (fd, 2) == NOTOK)
 		_exit (-1);
 	    closefds (3);
-#ifdef	BSD42
+#ifdef BSD42
 	    setpgrp (0, getpid ());
-#endif	/* BSD42 */
+#endif
 	    execvp (vec[0], vec);
 	    _exit (-1);
 
 	default: 
-	    switch (setjmp (myctx)) {
-		case OK: 
-		    signal (SIGALRM, alrmser);
-		    bytes = fstat (fileno (stdin), &st) != NOTOK
-			? (int) st.st_size : 100;
-		    if (bytes <= 0)
-			bytes = 100;
-		    alarm ((unsigned) (bytes * 60 + 300));
+	    if (!setjmp (myctx)) {
+		signal (SIGALRM, alrmser);
+		bytes = fstat(fileno (stdin), &st) != NOTOK ? (int) st.st_size : 100;
+		if (bytes <= 0)
+		    bytes = 100;
+		alarm ((unsigned) (bytes * 60 + 300));
 
-		    pidwait(child_id, OK);
+		pidwait(child_id, OK);
 
-		    alarm (0);
-		    if (fstat (fd, &st) != NOTOK && st.st_size > (off_t)0)
-			return fd;
-		    close (fd);
-		    return header_fd ();
-
-		default: 
-#ifndef	BSD42
-		    kill(child_id, SIGKILL);
-#else	/* BSD42 */
-		    killpg(child_id, SIGKILL);
-#endif	/* BSD42 */
-		    close (fd);
-		    return header_fd ();
+		alarm (0);
+		if (fstat (fd, &st) != NOTOK && st.st_size > (off_t)0)
+		    return fd;
+		close (fd);
+		return header_fd ();
+	    } else {
+		KILLPG(child_id, SIGKILL);
+		close (fd);
+		return header_fd ();
 	    }
     }
 }
@@ -240,11 +230,7 @@ header_fd (void)
     char tmpfil[BUFSIZ];
 
     strcpy (tmpfil, m_tmpfil (invo_name));
-    if ((fd = creat (tmpfil, 0600)) == NOTOK)
-	return NOTOK;
-    close (fd);
-
-    if ((fd = open (tmpfil, 2)) == NOTOK)
+    if ((fd = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
 	return NOTOK;
     unlink (tmpfil);
 
@@ -253,7 +239,7 @@ header_fd (void)
     if ( newline )
         write (fd, "\n\r", 2);
     write (fd, scanl, strlen (scanl));
-    if ( bell )
+    if (bell)
         write (fd, "\007", 1);
 
     return fd;
@@ -279,19 +265,16 @@ alert (char *tty, int md)
 		       )) == 0)
 	return;
 
-    switch (setjmp (myctx)) {
-	case OK: 
-	    signal (SIGALRM, alrmser);
-	    alarm (2);
-	    td = open (ttyspec, 1);
-	    alarm (0);
-	    if (td == NOTOK)
-		return;
-	    break;
-
-	default: 
-	    alarm (0);
+    if (!setjmp (myctx)) {
+	signal (SIGALRM, alrmser);
+	alarm (2);
+	td = open (ttyspec, 1);
+	alarm (0);
+	if (td == NOTOK)
 	    return;
+    } else {
+	alarm (0);
+	return;
     }
 
     lseek (md, (off_t) 0, 0);
