@@ -91,7 +91,7 @@ main (int argc, char **argv)
     if (interactive == -1)
 	interactive = defolder;
 
-    if (index (folder, '/') && (*folder != '/') && (*folder != '.')) {
+    if (strchr (folder, '/') && (*folder != '/') && (*folder != '.')) {
 	for (cp = copy (folder, newfolder); cp > newfolder && *cp != '/'; cp--)
 	    continue;
 	if (cp > newfolder)
