@@ -179,7 +179,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 		 * buffer as the component temp buffer (buffer switching
 		 * saves an extra copy of the component text).
 		 */
-		if (cptr = wantcomp[CHASH(name)])
+		if ((cptr = wantcomp[CHASH(name)]))
 		    do {
 			if (uleq(name, cptr->c_name)) {
 			    if (! cptr->c_text) {
@@ -195,7 +195,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 			    }
 			    break;
 			}
-		    } while (cptr = cptr->c_next);
+		    } while ((cptr = cptr->c_next));
 
 		while (state == FLDPLUS) {
 		    state = m_getfld (state, name, tmpbuf, rlwidth, inb);
@@ -318,7 +318,7 @@ finished:
     FINDCOMP (cptr, "encrypted");
     encrypted = cptr && cptr->c_text;
     /* return dynamically allocated buffers to pool */
-    while ( cptr = *savecomp++ ) {
+    while ((cptr = *savecomp++)) {
 	*--nxtbuf = cptr->c_text;
 	cptr->c_text = NULL;
     }
