@@ -9,6 +9,7 @@
 #include <h/signals.h>
 #include <setjmp.h>
 #include <signal.h>
+#include <fcntl.h>
 
 #ifdef MIME
 # include <h/mhn.h>
@@ -180,12 +181,12 @@ one_shot: ;
 	vec[vecp++] = "-queued";
 
     time (&clock);
-    sprintf (msgid, "<%d.%ld@%s>", getpid (), clock, LocalName ());
+    sprintf (msgid, "<%d.%ld@%s>", getpid(), clock, LocalName());
 
     fseek (in, start, 0);
     for (partno = 1; partno <= nparts; partno++) {
-	char    tmpdrf[BUFSIZ];
-	FILE   *out;
+	char tmpdrf[BUFSIZ];
+	FILE *out;
 
 	strcpy (tmpdrf, m_scratch (drft, invo_name));
 	if ((out = fopen (tmpdrf, "w")) == NULL)
@@ -209,7 +210,7 @@ one_shot: ;
 
 	pos = 0;
 	for (;;) {
-	    register long    len;
+	    register long len;
 
 	    if (!fgets (buffer, sizeof buffer - 1, in)) {
 		if (partno == nparts)
@@ -304,46 +305,43 @@ sendaux2 (char **vec, int vecp, char *drft, struct stat *st)
 
     for (i = 0; (child_id = vfork()) == NOTOK && i < 5; i++)
 	sleep (5);
-    switch (child_id) {
-	case NOTOK: 		/* oops */
-	    adios ("fork", "unable to");
 
-	case OK: 		/* send it */
-	    if (fd != NOTOK) {
-		dup2 (fd, fileno (stdout));
-		dup2 (fd, fileno (stderr));
-		close (fd);
-	    }
-	    execvp (postproc, vec);
-	    fprintf (stderr, "unable to exec ");
-	    perror (postproc);
-	    _exit (-1);
+    if (child_id == NOTOK) {
+	/* oops */
+	adios ("fork", "unable to");
+    } else if (!child_id) {
+	/* child process -- send it */
+	if (fd != NOTOK) {
+	    dup2 (fd, fileno (stdout));
+	    dup2 (fd, fileno (stderr));
+	    close (fd);
+	}
+	execvp (postproc, vec);
+	fprintf (stderr, "unable to exec ");
+	perror (postproc);
+	_exit (-1);
+    }
 
-	default: 		/* wait for it */
-	    if ((status = pidwait(child_id, NOTOK)) == 0) {
-		if (annotext && fd2 != NOTOK)
-		    anno (fd2, st);
-		if (splitsw < 0
-		        && rename (drft, strcpy (buf, m_backup (drft)))
-				== NOTOK)
-		    advise (buf, "unable to rename %s to", drft);
-	    }
-	    else {
-		if (fd != NOTOK) {
-		    alert (drft, fd);
-		    close (fd);
-		}
-		else
-		    advise (NULL, "message not delivered to anyone");
-		if (annotext && fd2 != NOTOK)
-		    close (fd2);
-		if (distfile) {
-		    unlink (drft);
-		    if (rename (backup, drft) == NOTOK)
-			advise (drft, "unable to rename %s to", backup);
-		}
-	    }
-	    break;
+    /* parent process -- wait for it */
+    if ((status = pidwait(child_id, NOTOK)) == 0) {
+	    if (annotext && fd2 != NOTOK)
+		anno (fd2, st);
+	    if (splitsw < 0 &&
+	        rename (drft, strcpy (buf, m_backup (drft))) == NOTOK)
+		advise (buf, "unable to rename %s to", drft);
+    } else {
+	if (fd != NOTOK) {
+	    alert (drft, fd);
+	    close (fd);
+	} else
+	    advise (NULL, "message not delivered to anyone");
+	if (annotext && fd2 != NOTOK)
+	    close (fd2);
+	if (distfile) {
+	    unlink (drft);
+	    if (rename (backup, drft) == NOTOK)
+		advise (drft, "unable to rename %s to", backup);
+	}
     }
 
     return status;
@@ -409,11 +407,7 @@ tmp_fd (void)
     char tmpfil[BUFSIZ];
 
     strcpy (tmpfil, m_tmpfil (invo_name));
-    if ((fd = creat (tmpfil, 0600)) == NOTOK)
-	return NOTOK;
-    close (fd);
-
-    if ((fd = open (tmpfil, 2)) == NOTOK)
+    if ((fd = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
 	return NOTOK;
     if (debugsw)
 	advise (NULL, "temporary file %s selected", tmpfil);
