@@ -5,48 +5,46 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
+
+#ifdef MIME
+# include <h/mhn.h>
+#endif
 
 static struct swit switches[] = {
-#define	DRFTSW	0
-    "draft", 5,
-
-#define	FORMSW	1
-    "form formfile", 4,
-#define	PROGSW	2
-    "moreproc program", 4,
-#define	NPROGSW	3
-    "nomoreproc", 3,
-#define	LENSW	4
-    "length lines", 4,
-#define	WIDSW	5
-    "width columns", 4,
-
-#define	SHOWSW	6
-    "showproc program", 4,
-#define	NSHOWSW	7
-    "noshowproc", 3,
-
-#define	HEADSW	8
-    "header", 4,
-#define	NHEADSW	9
-    "noheader", 3,
-
-#define	FILESW	10
-    "file file", -4,		/* interface from showfile */
-
-#define VERSIONSW 11
-    "version", 0,
-#define	HELPSW	12
-    "help", 4,
-
-    NULL, 0
+#define	DRFTSW               0
+    { "draft", 5 },
+#define	FORMSW               1
+    { "form formfile", 4 },
+#define	PROGSW               2
+    { "moreproc program", 4 },
+#define	NPROGSW              3
+    { "nomoreproc", 3 },
+#define	LENSW                4
+    { "length lines", 4 },
+#define	WIDSW                5
+    { "width columns", 4 },
+#define	SHOWSW               6
+    { "showproc program", 4 },
+#define	NSHOWSW              7
+    { "noshowproc", 3 },
+#define	HEADSW               8
+    { "header", 4 },
+#define	NHEADSW              9
+    { "noheader", 3 },
+#define	FILESW              10
+    { "file file", -4 },		/* interface from showfile */
+#define VERSIONSW           11
+    { "version", 0 },
+#define	HELPSW              12
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 /*
  * static prototypes
  */
-#ifdef	MIME
+#ifdef MIME
 static int nontext(char *);
 #endif
 
@@ -81,7 +79,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -132,7 +130,7 @@ main (int argc, char **argv)
 		    vec[vecp++] = --cp;
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
-		    vec[vecp++] = getcpy (libpath(cp));
+		    vec[vecp++] = getcpy (etcpath(cp));
 		    continue;
 
 		case PROGSW:
@@ -300,7 +298,6 @@ OfficialName (char *name)
 
 
 #ifdef MIME
-# include "../h/mhn.h"
 
 static int
 nontext (char *msgnam)
