@@ -1,6 +1,6 @@
 
 /*
- * slocal.c -- nmh style mailer to write to a local user's mailbox
+ * slocal.c -- asynchronously filter and deliver new mail
  *
  * $Id$
  */
@@ -8,20 +8,17 @@
 /*
  *  This program implements mail delivery in the MH/MMDF style.
  *
- *  Under SendMail, users should add the line
+ *  Under sendmail, users should add the line
  *
- * 	"| /usr/local/lib/mh/slocal"
+ * 	"| /usr/local/nmh/lib/slocal"
  *
  *  to their $HOME/.forward file.
  *
- *  Under MMDF-I, users should (symbolically) link /usr/local/lib/mh/slocal
- *  to $HOME/bin/rcvmail.
+ *  Under MMDF-I, users should (symbolically) link
+ *  /usr/local/nmh/lib/slocal to $HOME/bin/rcvmail.
  *
  *  Under stand-alone MH, post will automatically run this during local
  *  delivery.
- *
- *  This program should be used ONLY if you have "mts sendmail" or "mts mh"
- *  or "mts mmdf1" set in your MH configuration.
  */
 
 #include <h/mh.h>
@@ -34,55 +31,50 @@
 #include <sys/ioctl.h>
 #include <utmp.h>
 
-#ifdef MSGID
-# undef DBM		/* used by ndbm.h */
-# include <ndbm.h>
-# include <sys/file.h>
-# ifdef SYS5
-#  include <fcntl.h>
-# endif
-# if defined(LOCKF) && !defined(F_ULOCK)
-#  include <sys/fcntl.h>
-# endif  /* LOCKF */
-#endif
+#include <ndbm.h>
+#include <fcntl.h>
 
-#define	NVEC 100
 
 static struct swit switches[] = {
-#define	ADDRSW	0
+#define	ADDRSW         0
     { "addr address", 0 },
-#define	USERSW	1
+#define	USERSW         1
     { "user name", 0 },
-#define	FILESW	2
+#define	FILESW         2
     { "file file", 0 },
-#define	SENDSW	3
+#define	SENDSW         3
     { "sender address", 0 },
-#define	MBOXSW	4
+#define	MBOXSW         4
     { "mailbox file", 0 },
-#define	HOMESW	5
+#define	HOMESW         5
     { "home directory", -4 },
-#define	INFOSW	6
+#define	INFOSW         6
     { "info data", 0 },
-#define	MAILSW	7
+#define	MAILSW         7
     { "maildelivery file", 0 },
-#define	VERBSW	8
+#define	VERBSW         8
     { "verbose", 0 },
-#define	NVERBSW	9
+#define	NVERBSW        9
     { "noverbose", 0 },
-#define	DEBUGSW	10
+#define SUPPRESSDUP   10
+    { "suppressdup", 0 },
+#define NSUPPRESSDUP 11
+    { "nosuppressdup", 0 },
+#define	DEBUGSW       12
     { "debug", 0 },
-#define VERSIONSW 11
+#define VERSIONSW     13
     { "version", 0 },
-#define	HELPSW	12
+#define	HELPSW        14
     { "help", 4 },
     { NULL, 0 }
 };
 
-static int debug = 0;
 static int globbed = 0;
 static int parsed = 0;
 static int utmped = 0;
+static int suppressdup = 0;   /* are we suppressing duplicate messages? */
 static int verbose = 0;
+static int debug = 0;
 
 static char *addr = NULL;
 static char *user = NULL;
@@ -113,6 +105,8 @@ struct pair {
     char  p_flags;
 };
 
+#define	NVEC 100
+
 static struct pair hdrs[NVEC + 1] = {
     { "source",          NULL, P_HID },
     { "addr",            NULL, P_HID },
@@ -127,7 +121,8 @@ static struct pair hdrs[NVEC + 1] = {
     { "Resent-Sender",   NULL, P_ADR },
     { "Resent-To",       NULL, P_ADR },
     { "Resent-cc",       NULL, P_ADR },
-    NULL
+
+    { NULL, NULL, NULL }
 };
 
 static struct pair vars[] = {
@@ -136,7 +131,8 @@ static struct pair vars[] = {
     { "size",     NULL, P_NIL },
     { "reply-to", NULL, P_CHK },
     { "info",     NULL, P_NIL },
-    NULL
+
+    { NULL, NULL, NULL }
 };
 
 extern char **environ;
@@ -156,18 +152,15 @@ static int timely (char *, char *);
 static int usr_file (int, char *, char *);
 static int usr_pipe (int, char *, char *, char **);
 static RETSIGTYPE alrmser (int);
-static copyinfo (FILE *fp, char *);
+static void copyinfo (FILE *fp, char *);
 static int copyfile (int, char *, int);
 static void adorn (char *, char *, ...);
-
-#ifdef MSGID
-static int check_msgid (int, char *);
-#endif
+static int suppress_duplicates (int, char *);
 
 
 main (int argc, char **argv)
 {
-    int fd;
+    int fd, result;
     FILE *fp = stdin;
     char *cp, *mdlvr = NULL, buf[100];
     char from[BUFSIZ], mailbox[BUFSIZ];
@@ -241,6 +234,12 @@ main (int argc, char **argv)
 		    verbose = 0;
 		    continue;
 
+		case SUPPRESSDUP:
+		    suppressdup++;
+		    continue;
+		case NSUPPRESSDUP:
+		    suppressdup = 0;
+		    continue;
 		case DEBUGSW: 
 		    debug++;
 		    continue;
@@ -292,24 +291,37 @@ main (int argc, char **argv)
 
     setbuf (stdin, NULL);
 
-    if (file == NULL) {
-	if ((fd = copyfile (fileno (stdin), file = tmpfil, 1)) == NOTOK)
-	    adios (NULL, "unable to create temporary file");
+    /*
+     * Copy the message to a temporary file
+     */
+    if (file) {
+	int tempfd;
+
+	if ((tempfd = open (file, O_RDONLY)) == -1)
+	    adios(file, "unable to open");
 	if (debug)
-	    fprintf (stderr, "temporary file=\"%s\"\n", tmpfil);
-	else
-	    unlink (tmpfil);
-   	if ((fp = fdopen (fd, "r+")) == NULL)
-	    adios (NULL, "unable to access temporary file");
+	    fprintf (stderr, "retrieving message from file \"%s\"\n", file);
+	if ((fd = copyfile (tempfd, tmpfil, 1)) == -1)
+	    adios (NULL, "unable to create temporary file");
+	close (tempfd);
+    } else {
+	/* getting message from stdin */
+	if (debug)
+	    fprintf(stderr, "retrieving message from stdin\n");
+	if ((fd = copyfile (fileno (stdin), tmpfil, 1)) == -1)
+	    adios (NULL, "unable to create temporary file");
     }
+    if (debug)
+	fprintf (stderr, "temporary file=\"%s\"\n", tmpfil);
     else
-	fd = fileno (stdin);
+	unlink (tmpfil);
+    if (!(fp = fdopen (fd, "r+")))
+	adios (NULL, "unable to access temporary file");
 
     from[0] = 0;
     if (sender == NULL)
 	copyinfo (fp, from);
 
-
     if (mbox == NULL) {
 	sprintf (mailbox, "%s/%s",
 		mmdfldir[0] ? mmdfldir : pw->pw_dir,
@@ -327,7 +339,6 @@ main (int argc, char **argv)
 	fprintf (stderr, "addr=\"%s\"\n", addr);
 	fprintf (stderr, "user=\"%s\"\n", user);
 	fprintf (stderr, "info=\"%s\"\n", info);
-	fprintf (stderr, "file=\"%s\"\n", file);
 	fprintf (stderr, "sender=\"%s\"\n", sender);
 	fprintf (stderr, "mbox=\"%s\"\n", mbox);
 	fprintf (stderr, "home=\"%s\"\n", home);
@@ -336,19 +347,16 @@ main (int argc, char **argv)
 	fprintf (stderr, "now=%02d:%02d\n\n", now->tw_hour, now->tw_min);
     }
 
-    done (localmail (fd, from, mdlvr) != NOTOK ? RCV_MOK : RCV_MBX);
+    result = localmail (fd, from, mdlvr);
+    done (result != NOTOK ? RCV_MOK : RCV_MBX);
 }
 
+
 static int
 localmail (int fd, char *from, char *mdlvr)
 {
-#ifdef MSGID
-    struct stat st;
-
-    if (stat (".maildelivery.pag", &st) != NOTOK
-	    && check_msgid (fd, ".maildelivery") == DONE)
+    if (suppressdup && suppress_duplicates(fd, ".maildelivery") == DONE)
 	return OK;
-#endif
 
     if (usr_delivery (fd, mdlvr ? mdlvr : ".maildelivery", 0, from) != NOTOK)
 	return OK;
@@ -356,20 +364,20 @@ localmail (int fd, char *from, char *mdlvr)
     if (usr_delivery (fd, maildelivery, 1, from) != NOTOK)
 	return OK;
 
-#ifdef	notdef
+#if 0
     if (verbose)
 	printf ("(invoking hook)\n");
     if (usr_hook (fd, mbox) != NOTOK)
 	return OK;
-#endif	/* notdef */
+#endif
 
     if (verbose)
 	printf ("(trying normal delivery)\n");
     return usr_file (fd, mbox, from);
 }
 
-#define	matches(a,b) (stringdex (b, a) >= 0)
 
+#define	matches(a,b) (stringdex (b, a) >= 0)
 
 static int
 usr_delivery (int fd, char *delivery, int su, char *from)
@@ -385,7 +393,7 @@ usr_delivery (int fd, char *delivery, int su, char *from)
 	return NOTOK;
     if (fstat (fileno (fp), &st) == NOTOK
 	    || (st.st_uid != 0 && (su || st.st_uid != pw->pw_uid))
-	    || st.st_mode & 0022) {
+	    || st.st_mode & (S_IWGRP|S_IWOTH)) {
 	if (verbose) {
 	    printf ("%s: ownership/modes bad (%d, %d,%d,0%o)\n",
 		    delivery, su, pw->pw_uid, st.st_uid, st.st_mode);
@@ -396,28 +404,33 @@ usr_delivery (int fd, char *delivery, int su, char *from)
 
     won = 0;
     next = 1;
-    while (fgets (buffer, sizeof buffer, fp) != NULL) {
-	if (*buffer == '#')
+    while (fgets (buffer, sizeof(buffer), fp)) {
+	/* skip comments and empty lines */
+	if (*buffer == '#' || *buffer == '\n')
 	    continue;
-	if (cp = strchr(buffer, '\n'))
+	if ((cp = strchr(buffer, '\n')))
 	    *cp = 0;
-	if ((vecp = split (buffer, vec)) < 5)
+	if ((vecp = split (buffer, vec)) < 5) {
+	    if (debug)
+		fprintf (stderr, "WARNING: entry with only %d fields, skipping ...\n", vecp);
 	    continue;
-	if (debug)
+	}
+	if (debug) {
 	    for (i = 0; vec[i]; i++)
-		fprintf (stderr, "vec[%d]: \"%s\"\n", i, vec[i]);
+		fprintf (stderr, "vec[%d]: \"%s\" ", i, vec[i]);
+	    fprintf (stderr, "\n");
+	}
 
-	field = vec[0];
+	field   = vec[0];
 	pattern = vec[1];
-	action = vec[2];
+	action  = vec[2];
 
 	switch (vec[3][0]) {
 	    case 'N':
 	    case 'n':
- 		if (! next)
-			continue;  /* if previous condition failed, don't
-				      do this - else fall through */
-
+ 		if (!next)
+		    continue;  /* if previous condition failed, don't
+				  do this - else fall through */
 	    case '?': 
 		if (won)
 		    continue;	/* else fall */
@@ -514,7 +527,7 @@ usr_delivery (int fd, char *delivery, int su, char *from)
 		if (!uleq (action, "file"))
 		    continue;	/* else fall */
 	    case '>': 
-#ifdef	RPATHS
+#ifdef RPATHS
 		status = usr_file (fd, string,  from);	/* UUCP format? */
 #else
 		status = usr_file (fd, string,  NULL);
@@ -542,6 +555,7 @@ usr_delivery (int fd, char *delivery, int su, char *from)
     return (won ? OK : NOTOK);
 }
 
+
 #define	QUOTE	'\\'
 
 static int
@@ -550,7 +564,8 @@ split (char *cp, char **vec)
     register int i;
     register char *s;
 
-    for (i = 0, s = cp; i <= NVEC;) {
+    s = cp;
+    for (i = 0; i <= NVEC;) {
 	vec[i] = NULL;
 	while (isspace (*s) || *s == ',')
 	    *s++ = 0;
@@ -558,7 +573,7 @@ split (char *cp, char **vec)
 	    break;
 
 	if (*s == '"') {
-	    for (vec[i++] = ++s; *s != 0 && *s != '"'; s++)
+	    for (vec[i++] = ++s; *s && *s != '"'; s++)
 		if (*s == QUOTE) {
 		    if (*++s == '"')
 			strcpy (s - 1, s);
@@ -572,7 +587,7 @@ split (char *cp, char **vec)
 	    s--;
 	vec[i++] = s++;
 
-	while (*s != 0 && !isspace (*s) && *s != ',')
+	while (*s && !isspace (*s) && *s != ',')
 	    s++;
     }
     vec[i] = NULL;
@@ -580,6 +595,7 @@ split (char *cp, char **vec)
     return i;
 }
 
+
 static int
 parse (int fd)
 {
@@ -601,9 +617,9 @@ parse (int fd)
     }
     rewind (in);
 
-    if (p = lookup (hdrs, "source"))
+    if ((p = lookup (hdrs, "source")))
 	p->p_value = getcpy (sender);
-    if (p = lookup (hdrs, "addr"))
+    if ((p = lookup (hdrs, "addr")))
 	p->p_value = getcpy (addr);
 
     for (i = 0, state = FLD;;) {
@@ -619,7 +635,7 @@ parse (int fd)
 		for (p = hdrs; p->p_name; p++)
 		    if (uleq (p->p_name, name)) {
 			if (!(p->p_flags & P_HID)) {
-			    if (cp = p->p_value)
+			    if ((cp = p->p_value))
 				if (p->p_flags & P_ADR) {
 				    dp = cp + strlen (cp) - 1;
 				    if (*dp == '\n')
@@ -663,7 +679,7 @@ parse (int fd)
     }
     fclose (in);
 
-    if (p = lookup (vars, "reply-to")) {
+    if ((p = lookup (vars, "reply-to"))) {
 	if ((q = lookup (hdrs, "reply-to")) == NULL || q->p_value == NULL)
 	    q = lookup (hdrs, "from");
 	p->p_value = getcpy (q ? q->p_value : "");
@@ -680,6 +696,7 @@ parse (int fd)
     return OK;
 }
 
+
 #define	LPAREN	'('
 #define	RPAREN	')'
 
@@ -692,7 +709,7 @@ expand (char *s1, char *s2, int fd)
     if (!globbed)
 	glob (fd);
 
-    while (c = *s2++)
+    while ((c = *s2++))
 	if (c != '$' || *s2 != LPAREN)
 	    *s1++ = c;
 	else {
@@ -703,7 +720,7 @@ expand (char *s1, char *s2, int fd)
 		continue;
 	    }
 	    *s2++ = 0;
-	    if (p = lookup (vars, cp)) {
+	    if ((p = lookup (vars, cp))) {
 		if (!parsed && (p->p_flags & P_CHK))
 		    parse (fd);
 
@@ -714,6 +731,7 @@ expand (char *s1, char *s2, int fd)
     *s1 = 0;
 }
 
+
 static void
 glob (int fd)
 {
@@ -724,15 +742,15 @@ glob (int fd)
     if (globbed++)
 	return;
 
-    if (p = lookup (vars, "sender"))
+    if ((p = lookup (vars, "sender")))
 	p->p_value = getcpy (sender);
-    if (p = lookup (vars, "address"))
+    if ((p = lookup (vars, "address")))
 	p->p_value = getcpy (addr);
-    if (p = lookup (vars, "size")) {
+    if ((p = lookup (vars, "size"))) {
 	sprintf (buffer, "%d", fstat (fd, &st) != NOTOK ? (int) st.st_size : 0);
 	p->p_value = getcpy (buffer);
     }
-    if (p = lookup (vars, "info"))
+    if ((p = lookup (vars, "info")))
 	p->p_value = getcpy (info);
 
     if (debug)
@@ -741,18 +759,18 @@ glob (int fd)
 		    p - vars, p->p_name, p->p_value);
 }
 
+
 static struct pair *
 lookup (struct pair *pairs, char *key)
 {
-    register char *cp;
-
-    for (; cp = pairs->p_name; pairs++)
-	if (uleq (cp, key))
+    for (; pairs->p_name; pairs++)
+	if (uleq (pairs->p_name, key))
 	    return pairs;
 
     return NULL;
 }
 
+
 static int
 logged_in (void)
 {
@@ -779,12 +797,12 @@ logged_in (void)
 }
 
 
-static int
-timely (char *t1, char *t2)
-{
 #define	check(t,a,b)		if (t < a || t > b) return NOTOK
 #define	cmpar(h1,m1,h2,m2)	if (h1 < h2 || (h1 == h2 && m1 < m2)) return OK
 
+static int
+timely (char *t1, char *t2)
+{
     int t1hours, t1mins, t2hours, t2mins;
 
     if (sscanf (t1, "%d:%d", &t1hours, &t1mins) != 2)
@@ -803,6 +821,7 @@ timely (char *t1, char *t2)
     return NOTOK;
 }
 
+
 static int
 usr_file (int fd, char *mailbox, char *from)
 {
@@ -847,7 +866,8 @@ usr_file (int fd, char *mailbox, char *from)
     return OK;
 }
 
-#ifdef	notdef
+
+#if 0
 static int
 usr_hook (int fd, char *mailbox)
 {
@@ -895,7 +915,8 @@ usr_hook (int fd, char *mailbox)
 
     return i;
 }
-#endif	/* notdef */
+#endif
+
 
 static int
 usr_pipe (int fd, char *cmd, char *pgm, char **vec)
@@ -926,12 +947,12 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 		dup2 (fd, 3);
 	    closefds (4);
 
-#ifdef	TIOCNOTTY
-	    if ((fd = open ("/dev/tty", 2)) != NOTOK) {
+#ifdef TIOCNOTTY
+	    if ((fd = open ("/dev/tty", O_RDWR)) != NOTOK) {
 		ioctl (fd, TIOCNOTTY, NULL);
 		close (fd);
 	    }
-#endif	/* TIOCNOTTY */
+#endif /* TIOCNOTTY */
 
 #ifdef	BSD42
 	    setpgrp (0, getpid ());
@@ -946,44 +967,37 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 	    _exit (-1);
 
 	default: 
-	    switch (setjmp (myctx)) {
-		case OK: 
-		    signal (SIGALRM, alrmser);
-		    bytes = fstat (fd, &st) != NOTOK ? (int) st.st_size : 100;
-		    if (bytes <= 0)
-			bytes = 100;
-		    alarm ((unsigned) (bytes * 60 + 300));
+	    if (!setjmp (myctx)) {
+		signal (SIGALRM, alrmser);
+		bytes = fstat (fd, &st) != NOTOK ? (int) st.st_size : 100;
+		if (bytes <= 0)
+		    bytes = 100;
 
-		    status = pidwait (child_id, OK);
-
-		    alarm (0);
-#ifdef	MMDFI
-		    if (status == RP_MOK || status == RP_OK)
-			status = 0;
-#endif	/* MMDFI */
-		    if (verbose) {
-			if (status == 0)
-			    printf (", wins.\n");
+		alarm ((unsigned) (bytes * 60 + 300));
+		status = pidwait (child_id, OK);
+		alarm (0);
+#ifdef MMDFI
+		if (status == RP_MOK || status == RP_OK)
+		    status = 0;
+#endif
+		if (verbose) {
+		    if (status == 0)
+			printf (", wins.\n");
+		    else
+			if ((status & 0xff00) == 0xff00)
+			    printf (", system error\n");
 			else
-			    if ((status & 0xff00) == 0xff00)
-				printf (", system error\n");
-			    else
-				pidstatus (status, stdout, ", loses");
-			fflush (stdout);
-		    }
-		    return (status == 0 ? OK : NOTOK);
-
-		default: 
-#ifndef	BSD42
-		    kill (child_id, SIGKILL);
-#else	/* BSD42 */
-		    killpg (child_id, SIGKILL);
-#endif	/* BSD42 */
-		    if (verbose) {
-			printf (", timed-out; terminated\n");
-			fflush (stdout);
-		    }
-		    return NOTOK;
+			    pidstatus (status, stdout, ", loses");
+		    fflush (stdout);
+		}
+		return (status == 0 ? OK : NOTOK);
+	    } else {
+		KILLPG(child_id, SIGKILL);
+		if (verbose) {
+		    printf (", timed-out; terminated\n");
+		    fflush (stdout);
+		}
+		return NOTOK;
 	    }
     }
 }
@@ -996,7 +1010,7 @@ alrmser (int i)
 }
 
 
-static
+static void
 copyinfo (FILE *fp, char *from)
 {
     int i;
@@ -1015,7 +1029,7 @@ copyinfo (FILE *fp, char *from)
     }
 
     strcpy (buffer, from + i);
-    if (cp = strchr(buffer, '\n')) {
+    if ((cp = strchr(buffer, '\n'))) {
 	*cp = 0;
 	cp -= 24;
 	if (cp < buffer)
@@ -1034,17 +1048,16 @@ copyinfo (FILE *fp, char *from)
     rewind (fp);
 }
 
+
 static int
 copyfile (int qd, char *tmpfil, int fold)
 {
     register int i, first = 0, fd1, fd2;
-    char buffer[BUFSIZ]; register FILE  *qfp, *ffp;
+    char buffer[BUFSIZ];
+    register FILE *qfp, *ffp;
 
     strcpy (tmpfil, m_tmpfil (invo_name));
-    if ((fd1 = creat (tmpfil, 0600)) == NOTOK)
-	return NOTOK;
-    close (fd1);
-    if ((fd1 = open (tmpfil, 2)) == NOTOK)
+    if ((fd1 = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
 	return NOTOK;
 
     if (!fold) {
@@ -1084,10 +1097,10 @@ you_lose: ;
     }
 
     i = strlen ("From ");
-    while (fgets (buffer, sizeof buffer, qfp)) {
+    while (fgets (buffer, sizeof(buffer), qfp)) {
 	if (!strncmp (buffer, "From ", i))
 	    if (first == 0) {
-#ifdef  RPATHS
+#ifdef RPATHS
 		register char *fp, *cp, *hp, *ep;
 #endif
 		unixfrom = getcpy (buffer);     /* save for later */
@@ -1095,7 +1108,7 @@ you_lose: ;
 		continue;                       /* but don't put in file */
 #else
 		hp = cp = strchr(fp = unixfrom + i, ' ');
-		while (hp = strchr(++hp, 'r'))
+		while ((hp = strchr(++hp, 'r')))
 		    if (uprf (hp, "remote from")) {
 			hp = strrchr(hp, ' ');
 			break;
@@ -1159,10 +1172,15 @@ adorn (char *what, char *fmt, ...)
     invo_name = cp;
 }
 
-#ifdef MSGID
 
+/*
+ * Check ndbm/db file(s) to see if the Message-Id of this
+ * message matches the Message-Id of a previous message,
+ * so we can discard it.  If it doesn't match, we add the
+ * Message-Id of this message to the ndbm/db file.
+ */
 static int
-check_msgid (int fd, char *file)
+suppress_duplicates (int fd, char *file)
 {
     int	fd1, state;
     char *cp, buf[BUFSIZ], name[NAMESZ];
@@ -1172,14 +1190,15 @@ check_msgid (int fd, char *file)
 
     if ((fd1 = dup (fd)) == NOTOK)
 	return NOTOK;
-    if ((in = fdopen (fd1, "r")) == NULL) {
+    if (!(in = fdopen (fd1, "r"))) {
 	close (fd1);
 	return NOTOK;
     }
     rewind (in);
 
     for (state = FLD;;) {
-	switch (state = m_getfld (state, name, buf, sizeof buf, in)) {
+	state = m_getfld (state, name, buf, sizeof buf, in);
+	switch (state) {
 	    case FLD:
 	    case FLDPLUS:
 	    case FLDEOF:
@@ -1198,57 +1217,38 @@ check_msgid (int fd, char *file)
 		free (cp);
 		cp = key.dptr;
 
-		if ((db = dbm_open (file, O_RDWR | O_CREAT, 0600)) == NULL) {
+		if (!(db = dbm_open (file, O_RDWR | O_CREAT, 0600))) {
 		    advise (file, "unable to perform dbm_open on");
-out: ;
 		    free (cp);
 		    fclose (in);
 		    return NOTOK;
 		}
-# ifdef FCNTL
-		{
-		    struct flock fl;
-
-		    fl.l_type = F_WRLCK;
-		    fl.l_whence = 0;
-		    fl.l_start = 0;
-		    fl.l_len = 0;
-		    if (fcntl (dbm_pagfno (db), F_SETLK, &fl) == -1) {
-			advise (file, "unable to perform flock on");
-			goto out;
-		    }
+		if (lockfile(dbm_pagfno(db)) == -1) {
+		    advise (file, "unable to perform file locking on");
+		    free (cp);
+		    fclose (in);
+		    return NOTOK;
 		}
-# else
-#  ifdef LOCKF
-		if (lockf (dbm_pagfno (db), F_LOCK) == NOTOK) {
-		    advise (file, "unable to perform lockf on");
-		    goto out;
-		}
-#  else
-		if (flock (dbm_pagfno (db), LOCK_EX) == NOTOK) {
-		    advise (file, "unable to perform flock on");
-		    goto out;
-		}
-#  endif
-# endif
 
 		value = dbm_fetch (db, key);
-		if (value.dptr != NULL) {
-		    if (debug)
-		        advise (NULL,
-				"Message-ID: %s already received on\n\tDate:       %s",
-				cp, value.dptr);
+		if (value.dptr) {
+		    if (verbose)
+		        printf ("Message-ID: %s already received\non Date: %s", cp, value.dptr);
 		    free (cp);
 		    fclose (in);
 		    return DONE;
 		}
 			   
-		value.dsize = strlen (value.dptr =
-				      ddate + sizeof "Delivery-Date:") + 1;
+		value.dptr  = ddate + sizeof("Delivery-Date:");
+		value.dsize = strlen(value.dptr) + 1;
 
 		if (dbm_store (db, key, value, DBM_INSERT))
 		    advise (file, "possibly corrupt file");
 
+		/*
+		 * no need to unlock the dbm file(s), since we
+		 * immediately close them anyway.
+		 */
 		dbm_close (db);
 
 		free (cp);
@@ -1271,4 +1271,4 @@ out: ;
     fclose (in);
     return OK;
 }
-#endif /* MSGID */
+
