@@ -359,7 +359,7 @@ char   *mysndr;
 	adios (NULL, "no free file pointers");
 
     for (from[0] = sender[0] = NULL; mfgets (in, &hp) != DONE;)
-	if ((bp = index (hp, ':')) != NULL) {
+	if ((bp = strchr (hp, ':')) != NULL) {
 	    *bp++ = NULL;
 	    if (lequal (hp, "From"))
 		seekaddr (from, bp);
