@@ -5,8 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/signals.h"
+#include <h/mh.h>
+#include <h/signals.h>
 
 #if 0
 #if defined(SYS5) && !defined(TERMINFO)
@@ -46,8 +46,7 @@
 #endif	/* TERMINFO */
 #endif
 
-#include "../h/vmhsbr.h"
-#include <ctype.h>
+#include <h/vmhsbr.h>
 #include <errno.h>
 #include <setjmp.h>
 #include <signal.h>
@@ -234,7 +233,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++)
+    while ((cp = *argp++))
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
