@@ -10,8 +10,8 @@
  *     INI: include width of windows
  */
 
-#include "../h/mh.h"
-#include "../h/vmhsbr.h"
+#include <h/mh.h>
+#include <h/vmhsbr.h>
 
 static char *types[] = {
     "OK",
