@@ -64,7 +64,7 @@ main (int argc, char **argv)
     vec[vecp++] = "-library";
     vec[vecp++] = getcpy (m_maildir (""));
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -124,7 +124,7 @@ main (int argc, char **argv)
 	else
 	    vec[vecp++] = msg = cp;
     }
-    if (cp = m_find ("Aliasfile")) {	/* allow Aliasfile: profile entry */
+    if ((cp = m_find ("Aliasfile"))) {	/* allow Aliasfile: profile entry */
 	char *dp = NULL;
 
 	for (ap = brkstring(dp = getcpy(cp), " ", "\n"); ap && *ap; ap++) {
