@@ -108,10 +108,10 @@ client (char *args, char *protocol, char *service, int rproto, char *response)
     register struct netent *np;
 #endif
 
-#ifdef	KPOP
+#ifdef KPOP
     char *cp;
 
-    if (cp = index (kservice = service, '/')) {	/* "pop/kpop" */
+    if (cp = strchr (kservice = service, '/')) {	/* "pop/kpop" */
 	*cp++ = '\0';		/* kservice = "pop" */
 	service = cp;		/* service  = "kpop" */
     }
