@@ -7,15 +7,6 @@
 
 #include <h/mh.h>
 
-/*
- * (not true anymore)
- *
- * compile-time priority:
- *	LOCKF	use if defined
- *	FCNTL	use if SYS5  defined and LOCKF not defined
- *	FLOCK	use if BSD42 defined and LOCKF and SYS5 not defined
- */
-
 #ifdef MMDFONLY
 # define LOCKONLY
 #endif
@@ -64,6 +55,38 @@ static void timerON (char *, int);
 static void timerOFF (int);
 
 
+/*
+ * Lock the ndbm/db file containing the Message-Id's
+ * used for duplicate suppression.
+ */
+int
+lockfile (int fd)
+{
+#ifdef FCNTL
+    struct flock fl;
+ 
+    fl.l_type = F_WRLCK;
+    fl.l_whence = 0;
+    fl.l_start = 0;
+    fl.l_len = 0;
+    if (fcntl (fd, F_SETLK, &fl) == -1) 
+        return -1;
+#endif
+ 
+#ifdef LOCKF
+    if (lockf (fd, F_LOCK, 0L) == -1) 
+        return -1;
+#endif
+ 
+#ifdef FLOCK
+    if (flock (fd, LOCK_EX) == -1) 
+        return -1;
+#endif
+ 
+    return 0;
+}
+
+
 int
 lkopen (char *file, int access)
 {
@@ -211,9 +234,9 @@ f_lkopen (char *file, int access)
 	if ((fd = open (file, access | O_NDELAY)) == NOTOK)
 	    return NOTOK;
 
-# ifndef	LOCKF
-#  ifndef	FLOCK
-#   ifndef	FCNTL
+# ifndef LOCKF
+#  ifndef FLOCK
+#   ifndef FCNTL
 
 	/* should be an error? */
 #   else /* FCNTL */
@@ -273,9 +296,9 @@ lkclose (int fd, char *file)
     switch (lockstyle) {
 	case LOK_UNIX: 
 
-#ifndef		LOCKF
-# ifndef	FLOCK
-#  ifndef	FCNTL
+#ifndef LOCKF
+# ifndef FLOCK
+#  ifndef FCNTL
 	/* should be an error? */
 #  else	/* FCNTL */
 	    buf.l_type = F_UNLCK;
@@ -341,9 +364,9 @@ lkfclose (FILE *fp, char *file)
 
     switch (lockstyle) {
 	case LOK_UNIX: 
-#ifndef		LOCKF
-# ifndef	FLOCK
-#  ifndef	FCNTL
+#ifndef LOCKF
+# ifndef FLOCK
+#  ifndef FCNTL
 	/* should be an error? */
 #  else	/* FCNTL */
 	    buf.l_type = F_UNLCK;
